;;; scim-bridge-zh-si.el

;; Copyright (C) 2008 S. Irie
;; Copyright (C) 2008 Andy Stewart

;; Author: S. Irie
;; Maintainer: S. Irie
;; Keywords: Input Method, i18n

(defconst scim-bridge-zh-si-version "0.7.3")

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or
;; (at your option) any later version.

;; It is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
;; License for more details.

;; You should have received a copy of the GNU General Public
;; License along with this program; if not, write to the Free
;; Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
;; MA 02111-1307 USA

;;; Commentary:

;; The Smart Common Input Method platform (SCIM) is an input
;; method (IM) platform containing support for more than thirty
;; languages (CJK and many European languages) for POSIX-style
;; operating systems including Linux and BSD.

;; scim-bridge.el is SCIM-Bridge client for GNU Emacs. It is,
;; however, not part of official SCIM-Bridge.

;; This program changes the documentation strings of the variables
;; and functions defined in scim-bridge.el into the equivalents
;; which are written in Simplified Chinese.

;;
;; Installation:
;;
;; First, save this file (scim-bridge-zh-si.el) and scim-bridge.el
;; in a directory listed in load-path, and then byte-compile them.
;;
;; Put the following in your .emacs file:
;;
;;   (require 'scim-bridge-zh-si)
;;
;; After that, execute Emacs by typing on command line:
;;
;;   XMODIFIERS=@im=none emacs
;;
;; and turn on scim-mode:
;;
;;   M-x scim-mode
;;
;;
;; Here is the example of settings in .emacs:
;;
;;   (require 'scim-bridge-zh-si)
;;   ;; Use C-SPC for Set Mark command
;;   (scim-define-common-key ?\C-\  nil)
;;   ;; Use C-/ for Undo command
;;   (scim-define-common-key ?\C-/ nil)
;;   ;; Change cursor color depending on SCIM status
;;   (setq scim-cursor-color "red")
;;   ;; Turn on scim-mode automatically
;;   (scim-mode 1)
;;
;;
;; Note that this program requires GNU Emacs 22 or later, and
;; doesn't work when Emacs is running on terminal emulator.
;;

;; History:
;; 2008-12-28  S. Irie
;;         * Add/modify/delete translations
;;         * Version 0.7.3
;;
;; 2008-12-06  S. Irie
;;         * Add/modify/delete translations
;;         * Version 0.7.2
;;
;; 2008-10-20  S. Irie
;;         * Add/modify translations
;;         * Version 0.7.1
;;
;; 2008-10-08  S. Irie
;;         * First release
;;         * Version 0.7.0.1
;;
;; 2008-10-04  Andy Stewart
;;         * Translated from scim-bridge-en.el
;;         * Version 0.7.0

;; ToDo:

;;; Code:

(require 'scim-bridge)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Apply translations
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(scim-set-group-doc
 'scim
 "智能通用输入法平台")

(scim-set-variable-doc
 'scim-mode
 "切换 `scim-mode'.
直接设置这个变量没有效果;
使用 \\[customize] 或 函数 `scim-mode'.")

;; Basic settings
(scim-set-group-doc
 'scim-basic
 "操作设置, 例如模式设置和键盘设置")

(scim-set-variable-doc
 'scim-mode-local
 "如果值为非空 (non-nil), 输入法内容会对每一个缓存进行注册以使
各个缓存可以单独切换输入法. 否则, 输入法进行全局切换.")

(scim-set-variable-doc
 'scim-imcontext-temporary-for-minibuffer
 "如果为值为非空 (non-nil), 当在 minibuffer 输入内容时总是关闭 SCIM 的输入状态.
这个选项只有当选项 `scim-mode-local' 激活 (non-nil) 时才有效.")

(scim-set-variable-doc
 'scim-use-in-isearch-window
 "如果值为非空 (non-nil), SCIM可以在 `isearch-mode' 中使用.
否则, 不能在 `isearch-mode' 中使用.")

(scim-set-variable-doc
 'scim-use-minimum-keymap
 "如果值为非空 (non-nil), 当SCIM关闭时可打印字符事件不处理.
这个选项在避免和其他Emacs-Lisp库冲突时是有用的.")

(scim-set-variable-doc
 'scim-common-function-key-list
 "这个列表指示SCIM在直接插入模式和预编辑模式接管的按键.
你可以使用函数 `scim-define-common-key' 添加或删除其元素.
注意: 不要在这个选项设置前缀按键, 例如 ESC 或 C-X.
如果你要这么做, Emacs可能会变得不可操作.")

(scim-set-variable-doc
 'scim-preedit-function-key-list
 "这个列表指示SCIM在预编辑区域存在时接管的按键.
你可以使用函数 `scim-define-preedit-key' 添加或删除其元素.")

(scim-set-variable-doc
 'scim-use-kana-ro-key
 "如果你用jp-106键盘和日本kana输入法,
开启这个选项 (non-nil) 以使不按shift按键输入 kanna 字符 `ろ'.
这个选项可以使用 `xmodmap' 命令临时的修改 X-windows 系统的键盘设置.")

(scim-set-variable-doc
 'scim-simultaneous-pressing-time
 "如果你在 SCIM-Anthy 上使用日本的 thumb shift 输入法,
指定的时间设置 (秒) 相当于SCIM-Anthy里的 `同步按下时间' 设置.
在此时间间隔内的两个按键会被作为一个同步按键发送到SCIM."
 '(choice (const :tag "空的" nil)
          (number :tag "间隔 (秒.)" :value 0.1)))

(scim-set-variable-doc
 'scim-undo-by-committed-string
 "如果这个值为空 (nil),
撤销执行引起一些较短的待发字符串结合,
或者按一定的范围 (不超过20个字符) 划分长的待发字符串.
否则撤销在每一个待发字符串后执行.")

(scim-set-variable-doc
 'scim-clear-preedit-when-unexpected-event
 "当一个意想不到的事件发生在预编辑时, 预编辑区域被清空,
并设置这个值为非空 (non-nil).
意想不到的事件是指, 比如, 用鼠标粘贴字符串.")

;; Appearance
(scim-set-group-doc
 'scim-appearance
 "外观, 候选窗口, 等等.")

(scim-set-face-doc
 'scim-preedit-default-face
 "这个外观显示整个预编辑区域.")

(scim-set-face-doc
 'scim-preedit-underline-face
 "整个外观对应于SCIM图形设置工具文本中的 `下划线' 属性.")

(scim-set-face-doc
 'scim-preedit-highlight-face
 "整个外观对应于SCIM图形设置工具文本中的 `高亮' 属性.")

(scim-set-face-doc
 'scim-preedit-reverse-face
 "整个外观对应于SCIM图形设置工具文本中的 `反转' 属性.")

(scim-set-variable-doc
 'scim-cursor-color
 "如果这个值是一个字符串, 它指示出当 SCIM 开启时光标所应用的颜色.
如果这个值为一个单元,
它的第一个元素和第二个元素分别指示 SCIM 开启 和 关闭 时的光标颜色.
如果是一个列表,
它的第一, 二, 三项 (如果有的话) 元素分别指示 SCIM 开启, 关闭和禁止的光标颜色.
如果这个值为空 (nil) 意味着不控制光标的颜色.

注意这个选项需要 SCIM-Bridge 0.4.13 版本或更高."
 ;; ** Don't translate `:value' properties!! **
 '(choice (const :tag "空的" nil)
          (color :tag "红色" :format "红色 (%{sample%})\n" :value "red")
          (color :tag "蓝色" :format "蓝色 (%{sample%})\n" :value "blue")
          (color :tag "绿色" :format "绿色 (%{sample%})\n" :value "limegreen")
          (color :tag "其他" :value "red")
          (cons  :tag "其他 (开 . 关)"
                 (color :format "开: %v (%{sample%})  " :value "red")
                 (color :format "关: %v (%{sample%})\n" :value "blue"))
          (list  :tag "其他 (开 . 关)"
                 (color :format "开: %v (%{sample%})  " :value "red")
                 (color :format "关: %v (%{sample%})  禁止: none\n"
                        :value "blue"))
          (list  :tag "其他 (开 . 关 . 禁止)"
                 (color :format "开: %v (%{sample%})  " :value "red")
                 (color :format "关: %v (%{sample%})\n" :value "blue")
                 (color :format "禁止: %v (%{sample%})\n" :value "limegreen"))))

(scim-set-variable-doc
 'scim-isearch-cursor-type
 "这个选项指示当 `isearch-mode' 激活时光标的形状.
如果是 0, 这个选项不会被激活以致光标的形状不会被改变.
详细看 `光标类型'."
 '(choice (const :tag "默认 (0)" 0)
          (const :tag "使用框架参数" t)
          (const :tag "不显示" nil)
          (const :tag "填充方块" box)
          (const :tag "空心方块" hollow)
          (const :tag "垂直条" bar)
          (cons :tag "垂直条 (指定宽度)"
                (const :format "" bar)
                (integer :tag "宽度" :value 1))
          (const :tag "水平条" hbar)
          (cons :tag "水平条 (指定高度)"
                (const :format "" hbar)
                (integer :tag "高度" :value 1))))

(scim-set-variable-doc
 'scim-cursor-type-for-candidate
 "这个选项指定预编辑窗口显示候选变换时光标的形状.
如果为 0, 这个选项不会被激活以致光标的形状不会被改变.
详细看 `光标类型'."
 '(choice (const :tag "默认 (0)" 0)
          (const :tag "使用框架参数" t)
          (const :tag "不显示" nil)
          (const :tag "填充方块" box)
          (const :tag "空心方块" hollow)
          (const :tag "垂直条" bar)
          (cons :tag "垂直条 (指定宽度)"
                (const :format "" bar)
                (integer :tag "宽度" :value 1))
          (const :tag "水平条" hbar)
          (cons :tag "水平条 (指定高度)"
                (const :format "" hbar)
                (integer :tag "高度" :value 1))))

(scim-set-variable-doc
 'scim-put-cursor-on-candidate
 "如果这个值为非空 (non-nil) 时, 当预编辑区域显示候选转换时,
光标放在选择段的位置, 否则光标放在预编辑区域的顶端.")

(scim-set-variable-doc
 'scim-adjust-window-x-position
 "这个选项指定是否对候选窗口的位置进行调整, 候选窗口可能按纵向排列.
如果这个值为 `gnome', 会使用 GNOME 桌面环境的字体大小进行调整.
否则, 如果这个值是整数, 指示从正常位置处的进行调整的像素数量.
这个值不适用于候选窗口总是显示的输入法, 比如SCIM拼音输入法.
因为当光标在屏幕底部时, 窗口会隐藏光标."
 '(choice (const :tag "使用 GNOME 的字体大小" gnome)
          (integer :tag "指定像素数量" :value 24)
          (const :tag "关闭" nil)))

(scim-set-variable-doc
 'scim-adjust-window-y-position
 "如果这个值为非空 (non-nil), 候选窗口纵向位置会相对于命令 `xwininfo'
得到光标的底部进行调整. 否则, 不进行调整. 因此窗口可能会在精确位置的下面一点.")

(scim-set-variable-doc
 'scim-prediction-window-position
 "(只用于日本输入法) 这个值以 (位置 . 调整) 的形式给出.
如果 `位置' 的值为非空 (non-nil), 预想的窗口会显示在预编辑区域的开头.
如果 `调整' 的值为非空 (non-nil), 横向调整, 调整值和
`scim-adjust-window-x-position' 相同."
 '(cons
   (choice :tag "位置"
           (const :tag "预编辑区域的末尾" nil)
           (const :tag "预编辑区域的开头" t))
   (choice :tag "调整"
           (const :tag "和转换窗口一样" t)
           (const :tag "关闭" nil))))

(scim-set-variable-doc
 'scim-mode-line-string
 "这个变量指定一个当 `scim-mode' 激活时显示在模式栏上的描述 `scim-mode' 的字符串.")

;; Advanced settings
(scim-set-group-doc
 'scim-expert
 "高级设置")

(scim-set-variable-doc
 'scim-focus-update-interval
 "窗口聚焦是以秒为周期进行检查.
当SCIM关闭或输入聚焦到其他应用程序时,
`scim-focus-update-interval-long' 给出的一个较慢的时间周期会被替代使用.

注意当你系统里 SCIM-Bridge 的版本低于 0.4.13 或你的窗口管理器不支持
`_NET_ACTIVE_WINDOW' 参数时这个值不能使用.
在这种情况, 无论什么时候都使用`scim-focus-update-interval-long'.")

(scim-set-variable-doc
 'scim-focus-update-interval-long
 "这个值可能会观察输入聚焦并使用一个较慢的时间周期替换 `scim-focus-update-interval'.

详情查看 `scim-focus-update-interval'.")

(scim-set-variable-doc
 'scim-kana-ro-x-keysym
 "当日本 kana-RO 按键使用时, 这个选项指定事件对应于 X 窗口系统给出的
替代的按键系统符号. 这个程序设置替代按键系统为了从 yen-mark 按键中区别反斜线
符号按键.")

(scim-set-variable-doc
 'scim-kana-ro-key-symbol
 "当日本 kana-RO 按键使用时, 这个选项指定事件对应于 `scim-kana-ro-x-keysym'
给出的替代的按键系统符号. 这个程序设置替代按键系统为了从 yen-mark 按键中区别
反斜线符号按键."
 '(choice (symbol)
          (const :tag "空的" nil)))

(scim-set-variable-doc
 'scim-bridge-timeout
 "指定从SCIM接受数据的最大等待时间.
浮点数形式用于表示秒, 整数形式用于表示毫秒.")

(scim-set-variable-doc
 'scim-config-file
 "SCIM 配置文件的名称, 用于探测 SCIM 的设置改变.")

(scim-set-variable-doc
 'scim-meta-key-exists
 "如果键盘存在 mata 按键修改, 设置这个值为 t.
当自动判定不能很好工作时, 请在 `scim-bridge.el' 加载前手动设置这个值.")

(scim-set-variable-doc
 'scim-tmp-buffer-name
 "这个是用来和代理 (scim-agent) 进行通信的缓存的名字.")

(scim-set-variable-doc
 'scim-incompatible-mode-hooks
 "当这个勾子运行, `scim-mode-map' 不会被激活.")

(scim-set-variable-doc
 'scim-undo-command-list
 "当预编辑区域存在时这些命令变得不可用.")

;; Functions
(scim-set-function-doc
 'scim-set-group-doc
 "改变组的文档字符串.
如果字符串为空 (nil), 文档字符串保留原来的.")

(scim-set-function-doc
 'scim-set-variable-doc
 "改变变量的文档字符串.
如果字符串为空 (nil), 文档字符串保留原来的.
如果自定义类型为非空 (non-nil), 它设置为变量的 `custom-type' 属性,
符合 `defcustom' 中的 `:type' 关键字.")

(scim-set-function-doc
 'scim-set-face-doc
 "改变外观的文档字符串.
如果字符串为空 (nil), 文档字符串保留原来的.")

(scim-set-function-doc
 'scim-define-common-key
 "SCIM在预编辑时接管的特殊的按键事件.
如果操作为非空 (non-nil), SCIM根据给出的按键进行按键事件操作.
当给出的按键是一个数组时, 它不会指示按键序列, 但是对单一按键进行多重定义.
当调用函数 `scim-update-key-bindings' 或重新启动 `scim-mode' 以使设置生效时
这个值是必需的.")

(scim-set-function-doc
 'scim-define-preedit-key
 "SCIM在预编辑时接管的特殊的按键事件.
如果操作为非空 (non-nil), SCIM根据给出的按键进行按键事件操作.
当给出的按键是一个数组时, 它不会指示按键序列, 但是对单一按键进行多重定义.
当调用函数 `scim-update-key-bindings' 或重新启动 `scim-mode' 以使设置生效时
这个值是必需的.")

(scim-set-function-doc
 'scim-reset-imcontext-statuses
 "重新设置所有缓存的输入状态以改正不适当的光标颜色.
这个函数可能会在使用 SCIM 图形设置工具后调用.")

(scim-set-function-doc
 'scim-get-frame-extents
 "返回框架边缘的像素宽度 (左边 右边 顶部 底部).
这里 `顶部' 是指框架标题栏的高度.")

(scim-set-function-doc
 'scim-frame-header-height
 "返回菜单栏和工具栏的总的高度.
这个函数返回的值不是那么精确.")

(scim-set-function-doc
 'scim-real-frame-header-height
 "返回菜单栏和工具栏的总的高度.
这个函数返回的值非常精确, 但是这个函数比 `scim-frame-header-height' 要慢很多.")

(scim-set-function-doc
 'scim-compute-pixel-position
 "返回屏幕上点的像素位置 (X轴 . Y轴).
这个值显示字符左上角的坐标.")

(scim-set-function-doc
 'scim-get-gnome-font-size
 "返回GNOME环境中应用字体的像素大小.
当设置屏幕分辨率(点/英寸)时这个值是必需的, 使用命令 `gconftool-2'.
不然的话, 这个函数返回零.")

(scim-set-function-doc
 'scim-get-active-window-id
 "返回窗口系统中前台窗口的标识数字,
也就是输入聚焦的窗口.")


(scim-set-function-doc
 'scim-enable-isearch
 "使SCIM可以在 `isearch-mode' 中使用.")

(scim-set-function-doc
 'scim-disable-isearch
 "使SCIM不可以在 `isearch-mode' 中使用.")

(scim-set-function-doc
 'scim-mode
 "切换 `SCIM' 模式.
如果可选参数是正数, 开启 `scim-mode',
否则, 关闭它.")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Define functions useful only for Simplified Chinese
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Settings

;; Functions

;;  (No such functions)

(provide 'scim-bridge-zh-si)

;;;
;;; scim-bridge-zh-si.el ends here
